@@ -21,6 +21,7 @@ from .basemaps import basemaps
 from ._version import EXTENSION_VERSION
 
 def_loc = [0.0, 0.0]
+allowed_crs = ['Earth', 'EPSG3395', 'EPSG3857', 'EPSG4326', 'Base', 'Simple']
 
 
 def basemap_to_tiles(bm, day='yesterday', **kwargs):
@@ -74,8 +75,9 @@ class Layer(Widget, InteractMixin):
     base = Bool(False).tag(sync=True)
     bottom = Bool(False).tag(sync=True)
     popup = Instance(Widget, allow_none=True, default_value=None).tag(sync=True, **widget_serialization)
-    popup_min_width = Int(400).tag(sync=True)
-    popup_max_height = Int(400).tag(sync=True)
+    popup_min_width = Int(50).tag(sync=True)
+    popup_max_width = Int(300).tag(sync=True)
+    popup_max_height = Int(default_value=None, allow_none=True).tag(sync=True)
 
     options = List(trait=Unicode).tag(sync=True)
 
@@ -191,8 +193,9 @@ class Popup(UILayer):
     ).tag(sync=True, **widget_serialization)
 
     # Options
-    min_width = Int(400).tag(sync=True, o=True)
-    max_height = Int(400).tag(sync=True, o=True)
+    min_width = Int(50).tag(sync=True, o=True)
+    max_width = Int(300).tag(sync=True, o=True)
+    max_height = Int(default_value=None, allow_none=True).tag(sync=True, o=True)
     auto_pan = Bool(True).tag(sync=True, o=True)
     auto_pan_padding_top_left = List(allow_none=True, default_value=None).tag(sync=True, o=True)
     auto_pan_padding_bottom_right = List(allow_none=True, default_value=None).tag(sync=True, o=True)
@@ -258,7 +261,7 @@ class WMSLayer(TileLayer):
     styles = Unicode().tag(sync=True, o=True)
     format = Unicode('image/jpeg').tag(sync=True, o=True)
     transparent = Bool(False).tag(sync=True, o=True)
-    crs = Unicode(allow_none=True, default_value=None).tag(sync=True, o=True)
+    crs = Enum(values=allowed_crs, default_value='EPSG3857').tag(sync=True)
     uppercase = Bool(False).tag(sync=True, o=True)
 
 
@@ -552,11 +555,30 @@ class Control(Widget):
 
     options = List(trait=Unicode).tag(sync=True)
 
+    position = Enum(
+        ['topright', 'topleft', 'bottomright', 'bottomleft'],
+        default_value='topleft',
+        help="""Possible values are topleft, topright, bottomleft
+                or bottomright"""
+    ).tag(sync=True, o=True)
+
     @default('options')
     def _default_options(self):
         return [name for name in self.traits(o=True)]
 
 
+class WidgetControl(Control):
+    _view_name = Unicode('LeafletWidgetControlView').tag(sync=True)
+    _model_name = Unicode('LeafletWidgetControlModel').tag(sync=True)
+
+    widget = Instance(DOMWidget).tag(sync=True, **widget_serialization)
+
+    max_width = Int(default_value=None, allow_none=True).tag(sync=True)
+    min_width = Int(default_value=None, allow_none=True).tag(sync=True)
+    max_height = Int(default_value=None, allow_none=True).tag(sync=True)
+    min_height = Int(default_value=None, allow_none=True).tag(sync=True)
+
+
 class FullScreenControl(Control):
     _view_name = Unicode('LeafletFullScreenControlView').tag(sync=True)
     _model_name = Unicode('LeafletFullScreenControlModel').tag(sync=True)
@@ -576,13 +598,6 @@ class MeasureControl(Control):
     _custom_units_dict = {}
     _custom_units = Dict().tag(sync=True)
 
-    position = Enum(
-        ['topright', 'topleft', 'bottomright', 'bottomleft'],
-        default_value='topright',
-        help="""Possible values are topleft, topright, bottomleft
-                or bottomright"""
-    ).tag(sync=True, o=True)
-
     primary_length_unit = Enum(
         values=_length_units,
         default_value='feet',
@@ -748,6 +763,7 @@ class Map(DOMWidget, InteractMixin):
     max_zoom = Int(18).tag(sync=True, o=True)
     min_zoom = Int(1).tag(sync=True, o=True)
     interpolation = Unicode('bilinear').tag(sync=True, o=True)
+    crs = Enum(values=allowed_crs, default_value='EPSG3857').tag(sync=True)
 
     # Specification of the basemap
     basemap = Dict(default_value=dict(
